@@ -1,12 +1,12 @@
 #!/usr/bin/python3
 
-"""Add replace method improvements.
+"""Add replace method improvements
 
-Library to add some replace method improvementsfocused on
+Library to add some replace method improvements focused on
 common replacements to optimize code.
 """
 
-from .core import ImprovedReplace
+from .core import to_array, to_comma, to_point
 
 __tittle__ = "improved replace"
 __url__ = "https://github.com/LuckJMG/ImprovedReplace"
@@ -14,6 +14,6 @@ __author__ = "LuckJMG"
 __email__ = "lucas.mosquera13@gmail.com"
 __license__ = "MIT license"
 __copyright__ = "Copyright 2020, LuckJMG"
-__version__ = "1.2.3"
+__version__ = "1.3.0"
 __status__ = "Production"
-__all__ = ["ImprovedReplace"]
+__all__ = ["to_array", "to_comma", "to_point"]
